"""
:authors: Vladislav117
:license: Apache License, Version 2.0, see LICENSE file
:copyright: (c) 2021 Vladislav117
"""

from .geometry import *

__author__ = "Vladislav117"
__version__ = "0.0.1"
__email__ = "siluetkysta@gmail.com"
